@@ -1,9 +1,10 @@
 #' spec_connection_disconnect
+#' @family connection specifications
 #' @usage NULL
 #' @format NULL
-#' @keywords internal
+#' @keywords NULL
 spec_connection_disconnect <- list(
-  disconnect_formals = function(ctx) {
+  disconnect_formals = function() {
     # <establish formals of described functions>
     expect_equal(names(formals(dbDisconnect)), c("conn", "..."))
   },
@@ -15,25 +16,22 @@ spec_connection_disconnect <- list(
     expect_invisible_true(dbDisconnect(con))
   },
 
-  #' @section Specification:
+  #'
+  #' @section Failure modes:
   #' A warning is issued on garbage collection when a connection has been
   #' released without calling `dbDisconnect()`,
   #' but this cannot be tested automatically.
 
   #' A warning is issued immediately when calling `dbDisconnect()` on an
   #' already disconnected
-  disconnect_closed_connection = function(ctx) {
-    with_closed_connection({
-      expect_warning(dbDisconnect(con))
-    })
+  disconnect_closed_connection = function(ctx, closed_con) {
+    expect_warning(dbDisconnect(closed_con))
   },
 
   #' or invalid connection.
-  disconnect_invalid_connection = function(ctx) {
-    with_invalid_connection({
-      expect_warning(dbDisconnect(con))
-    })
+  disconnect_invalid_connection = function(ctx, invalid_con) {
+    expect_warning(dbDisconnect(invalid_con))
   },
-
+  #
   NULL
 )
