@@ -1,7 +1,8 @@
 #' spec_driver_get_info
+#' @family driver specifications
 #' @usage NULL
 #' @format NULL
-#' @keywords internal
+#' @keywords NULL
 #' @name spec_get_info
 spec_driver_get_info <- list(
   #' @return
@@ -25,9 +26,10 @@ spec_driver_get_info <- list(
 
     for (name in necessary_names) {
       eval(bquote(
-        expect_true(.(name) %in% info_names)))
+        expect_true(.(name) %in% info_names)
+      ))
     }
   },
-
+  #
   NULL
 )
