@@ -12,8 +12,21 @@ test_that("no unnamed specs", {
   expect_null(vicinity)
 })
 
-test_that("no duplicate spec names", {
+test_that("no duplicate spec names expect known exceptions", {
   all_names <- names(spec_all)
+
+  all_names <- all_names[!(all_names %in% c(
+    "create_temporary_table",
+    "create_table_visible_in_other_connection",
+    "list_tables",
+    "exists_table",
+    "temporary_table",
+    "list_objects",
+    "table_visible_in_other_connection",
+    "begin_write_disconnect",
+    "begin_write_commit"
+  ))]
+
   dupe_names <- unique(all_names[duplicated(all_names)])
   expect_equal(dupe_names, rep("", length(dupe_names)))
 })
