@@ -1,6 +1,6 @@
 context("tweaks")
 
-test_that("multiplication works", {
+test_that("tweaks work as expected", {
   expect_true(names(formals(tweaks))[[1]] == "...")
   expect_warning(tweaks(`_oooops` = 42, `_darn` = -1), "_oooops, _darn")
   expect_warning(tweaks(), NA)
